LoggerGlue uses glue::glue() instead of base::sprintf() to construct
log messages. glue is a very well designed package for
string interpolation. It makes composing log messages
more flexible and comfortable at the price of an additional dependency and
slightly less performance than sprintf().
lgr::Filterable -> lgr::Logger -> LoggerGlue
fatal()LoggerGlue$fatal(..., caller = get_caller(-8L), .envir = parent.frame())
error()LoggerGlue$error(..., caller = get_caller(-8L), .envir = parent.frame())
warn()LoggerGlue$warn(..., caller = get_caller(-8L), .envir = parent.frame())
info()LoggerGlue$info(..., caller = get_caller(-8L), .envir = parent.frame())
debug()LoggerGlue$debug(..., caller = get_caller(-8L), .envir = parent.frame())
trace()LoggerGlue$trace(..., caller = get_caller(-8L), .envir = parent.frame())
log()LoggerGlue$log( level, ..., timestamp = Sys.time(), caller = get_caller(-7), .envir = parent.frame() )
list_log()LoggerGlue$list_log(x)
spawn()LoggerGlue$spawn(name)
glue() lets you define temporary named variables inside the call.
As with the normal Logger, these named arguments get turned into custom
fields; however, you can suppress this behaviour by making named argument
start with a ".". Please refer to vignette("lgr", package = "lgr") for
examples.